import { defineMiddleware, sequence } from "astro:middleware";

const protectedRoutes = defineMiddleware(async (ctx, next) => {
	const pathname = ctx.url.pathname;
	if (!["/", "/register"].includes(pathname)) {
		const jwt = ctx.cookies.get("token");
		if (!jwt) {
			return ctx.redirect("/");
		}

		const res = await fetch(
			`${import.meta.env.PUBLIC_API_URL}/accounts/recovery`,
			{
				credentials: "include",
				headers: ctx.request.headers,
			},
		);

		if (res.status !== 201) {
			return ctx.redirect("/");
		}

		ctx.locals.account = JSON.parse(await res.text()).account;
	}

	return await next();
});

export const onRequest = sequence(defineMiddleware(protectedRoutes));
